"use client"

import { useSortable } from "@dnd-kit/sortable"
import { CSS } from "@dnd-kit/utilities"
import { ReactNode } from "react"

type Props = {
  id: string
  children: ReactNode
}

export default function SortableItemCard({ id, children }: Props) {
  const {
    attributes,
    listeners,
    setNodeRef,
    transform,
    transition,
    isDragging,
  } = useSortable({ id })

  const style = {
    transform: CSS.Transform.toString(transform),
    transition,
    zIndex: isDragging ? 40 : "auto",
    opacity: isDragging ? 0.7 : 1,
  }

  return (
    <div
      ref={setNodeRef}
      style={style}>
      <div
        {...attributes}
        {...listeners}
        className="cursor-grab px-2 py-1 text-sm text-muted-foreground"
        title="Drag to reorder"
      >
        ☰
      </div>
      {children}
    </div>
  )
}
